@@ -1,9 +1,121 @@
 from design_bench.disk_resource import DiskResource
-from collections.abc import Iterable
 import numpy as np
 import abc
 
 
+def default_uniform_distribution(ranks):
+    """Accepts the rank of a set of designs as input and returns an
+    un-normalized uniform probability distribution
+
+    Arguments:
+
+    ranks: np.ndarray
+        a numpy array representing the rank order of a set of designs given
+        by their y values in a model-based optimization dataset
+
+    Returns:
+
+    probabilities: np.ndarray
+        an un-normalized probability distribution that is passed to
+        np.random.choice to subsample a model-based optimization dataset
+
+    """
+
+    return np.ones(ranks.shape, dtype=np.float32)
+
+
+def default_linear_distribution(ranks):
+    """Accepts the rank of a set of designs as input and returns an
+    un-normalized linear probability distribution
+
+    Arguments:
+
+    ranks: np.ndarray
+        a numpy array representing the rank order of a set of designs given
+        by their y values in a model-based optimization dataset
+
+    Returns:
+
+    probabilities: np.ndarray
+        an un-normalized probability distribution that is passed to
+        np.random.choice to subsample a model-based optimization dataset
+
+    """
+
+    ranks = ranks.astype(np.float32)
+    ranks = ranks / ranks.max()
+    return 1.0 - ranks
+
+
+def default_quadratic_distribution(ranks):
+    """Accepts the rank of a set of designs as input and returns an
+    un-normalized quadratic probability distribution
+
+    Arguments:
+
+    ranks: np.ndarray
+        a numpy array representing the rank order of a set of designs given
+        by their y values in a model-based optimization dataset
+
+    Returns:
+
+    probabilities: np.ndarray
+        an un-normalized probability distribution that is passed to
+        np.random.choice to subsample a model-based optimization dataset
+
+    """
+
+    ranks = ranks.astype(np.float32)
+    ranks = ranks / ranks.max()
+    return (1.0 - ranks)**2
+
+
+def default_circular_distribution(ranks):
+    """Accepts the rank of a set of designs as input and returns an
+    un-normalized circular probability distribution
+
+    Arguments:
+
+    ranks: np.ndarray
+        a numpy array representing the rank order of a set of designs given
+        by their y values in a model-based optimization dataset
+
+    Returns:
+
+    probabilities: np.ndarray
+        an un-normalized probability distribution that is passed to
+        np.random.choice to subsample a model-based optimization dataset
+
+    """
+
+    ranks = ranks.astype(np.float32)
+    ranks = ranks / ranks.max()
+    return 1.0 - np.sqrt(1.0 - (ranks - 1.0)**2)
+
+
+def default_exponential_distribution(ranks, c=3.0):
+    """Accepts the rank of a set of designs as input and returns an
+    un-normalized exponential probability distribution
+
+    Arguments:
+
+    ranks: np.ndarray
+        a numpy array representing the rank order of a set of designs given
+        by their y values in a model-based optimization dataset
+
+    Returns:
+
+    probabilities: np.ndarray
+        an un-normalized probability distribution that is passed to
+        np.random.choice to subsample a model-based optimization dataset
+
+    """
+
+    ranks = ranks.astype(np.float32)
+    ranks = ranks / ranks.max()
+    return np.exp(-c * ranks)
+
+
 class DatasetBuilder(abc.ABC):
     """An abstract base class that defines a common set of functions
     and attributes for a model-based optimization dataset, where the
@@ -55,6 +167,9 @@ class DatasetBuilder(abc.ABC):
     dataset_size: int
         the total number of paired design values 'x' and prediction values
         'y' in the dataset, represented as a single integer
+    dataset_distribution: Callable[np.ndarray, np.ndarray]
+        the target distribution of the model-based optimization dataset
+        marginal p(y) used for controlling the sampling distribution
     dataset_max_percentile: float
         the percentile between 0 and 100 of prediction values 'y' above
         which are hidden from access by members outside the class
@@ -110,6 +225,7 @@ class DatasetBuilder(abc.ABC):
         optimization data set for training a model
 
     subsample(max_samples: int,
+              distribution: Callable[np.ndarray, np.ndarray],
               max_percentile: float,
               min_percentile: float):
         a function that exposes a subsampled version of a much larger
@@ -225,7 +341,8 @@ class DatasetBuilder(abc.ABC):
 
     def __init__(self, x_shards, y_shards, internal_batch_size=32,
                  is_normalized_x=False, is_normalized_y=False,
-                 max_samples=None, max_percentile=100.0, min_percentile=0.0):
+                 max_samples=None, distribution=None,
+                 max_percentile=100.0, min_percentile=0.0):
         """Initialize a model-based optimization dataset and prepare
         that dataset by loading that dataset from disk and modifying
         its distribution of designs and predictions
@@ -256,6 +373,10 @@ class DatasetBuilder(abc.ABC):
             the maximum number of samples to include in the visible dataset;
             if more than this number of samples would be present, samples
             are randomly removed from the visible dataset
+        distribution: Callable[np.ndarray, np.ndarray]
+            a function that accepts an array of the ranks of designs as
+            input and returns the probability to sample each according to
+            a distribution---for example, a geometric distribution
         max_percentile: float
             the percentile between 0 and 100 of prediction values 'y' above
             which are hidden from access by members outside the class
@@ -267,9 +388,11 @@ class DatasetBuilder(abc.ABC):
 
         # save the provided dataset shards to be loaded into batches
         self.x_shards = (x_shards,) if \
-            not isinstance(x_shards, Iterable) else x_shards
+            isinstance(x_shards, np.ndarray) or \
+            isinstance(x_shards, DiskResource) else x_shards
         self.y_shards = (y_shards,) if \
-            not isinstance(y_shards, Iterable) else y_shards
+            isinstance(y_shards, np.ndarray) or \
+            isinstance(y_shards, DiskResource) else y_shards
 
         # download the remote resources if they are given
         self.num_shards = 0
@@ -287,6 +410,7 @@ class DatasetBuilder(abc.ABC):
         self.dataset_max_percentile = 100.0
         self.dataset_min_output = np.NINF
         self.dataset_max_output = np.PINF
+        self.dataset_distribution = None
 
         # initialize the normalization state to False
         self.internal_batch_size = internal_batch_size
@@ -337,6 +461,7 @@ class DatasetBuilder(abc.ABC):
         if is_normalized_y:
             self.map_normalize_y()
         self.subsample(max_samples=max_samples,
+                       distribution=distribution,
                        min_percentile=min_percentile,
                        max_percentile=max_percentile)
 
@@ -860,7 +985,7 @@ class DatasetBuilder(abc.ABC):
         # reset the normalized state to what it originally was
         self.is_normalized_y = original_is_normalized_y
 
-    def subsample(self, max_samples=None,
+    def subsample(self, max_samples=None, distribution=None,
                   max_percentile=100.0, min_percentile=0.0):
         """a function that exposes a subsampled version of a much larger
         model-based optimization dataset containing design values 'x'
@@ -872,6 +997,10 @@ class DatasetBuilder(abc.ABC):
             the maximum number of samples to include in the visible dataset;
             if more than this number of samples would be present, samples
             are randomly removed from the visible dataset
+        distribution: Callable[np.ndarray, np.ndarray]
+            a function that accepts an array of the ranks of designs as
+            input and returns the probability to sample each according to
+            a distribution---for example, a geometric distribution
         max_percentile: float
             the percentile between 0 and 100 of prediction values 'y' above
             which are hidden from access by members outside the class
@@ -913,19 +1042,37 @@ class DatasetBuilder(abc.ABC):
         self.dataset_max_percentile = max_percentile
         self.dataset_max_output = max_output
 
-        # calculate indices of samples that are visible
+        # calculate indices of samples that are within range
         indices = np.arange(y.shape[0])[np.where(
             np.logical_and(y <= max_output, y >= min_output))[0]]
         max_samples = indices.size \
             if max_samples is None else min(indices.size, max_samples)
+
+        # replace default distributions with their implementations
+        if distribution in {None, "uniform"}:
+            distribution = default_uniform_distribution
+        elif distribution == "linear":
+            distribution = default_linear_distribution
+        elif distribution == "quadratic":
+            distribution = default_quadratic_distribution
+        elif distribution == "exponential":
+            distribution = default_exponential_distribution
+        elif distribution == "circular":
+            distribution = default_circular_distribution
+
+        # calculate the probability to subsample individual designs
+        probs = distribution(y[indices, 0].argsort().argsort())
+        probs = np.asarray(probs, dtype=np.float32)
+        probs = np.broadcast_to(probs, (indices.size,))
         indices = indices[np.random.choice(
-            indices.size, max_samples, replace=False)]
-        self.dataset_size = indices.size
+            indices.size, max_samples, replace=False, p=probs / probs.sum())]
 
         # binary mask that determines which samples are visible
         visible_mask = np.full([y.shape[0]], False, dtype=np.bool)
         visible_mask[indices] = True
         self.dataset_visible_mask = visible_mask
+        self.dataset_size = indices.size
+        self.dataset_distribution = distribution
 
         # update normalization statistics for design values
         if self.is_normalized_x:
@@ -1069,6 +1216,7 @@ class DatasetBuilder(abc.ABC):
         # re-sample the data set and recalculate statistics
         self._disable_subsample = False
         self.subsample(max_samples=self.dataset_size,
+                       distribution=self.dataset_distribution,
                        max_percentile=self.dataset_max_percentile,
                        min_percentile=self.dataset_min_percentile)
 
@@ -1126,6 +1274,7 @@ class DatasetBuilder(abc.ABC):
         dataset.dataset_max_percentile = self.dataset_max_percentile
         dataset.dataset_min_output = self.dataset_min_output
         dataset.dataset_max_output = self.dataset_max_output
+        dataset.dataset_distribution = self.dataset_distribution
 
         # calculate indices of samples that are visible
         dataset.dataset_visible_mask = visible_mask
