@@ -1,6 +1,6 @@
 from design_bench.oracles.oracle_builder import OracleBuilder
 from design_bench.datasets.dataset_builder import DatasetBuilder
-from design_bench.disk_resource import DiskResource
+from design_bench.disk_resource import DiskResource, SERVER_URL
 from scipy import stats
 import numpy as np
 import pickle as pkl
@@ -261,6 +261,10 @@ class ApproximateOracle(OracleBuilder, abc.ABC):
             the maximum number of samples to include in the visible dataset;
             if more than this number of samples would be present, samples
             are randomly removed from the visible dataset
+        distribution: Callable[np.ndarray, np.ndarray]
+            a function that accepts an array of the ranks of designs as
+            input and returns the probability to sample each according to
+            a distribution---for example, a geometric distribution
         max_percentile: float
             the percentile between 0 and 100 of prediction values 'y' above
             which are hidden from access by members outside the class
@@ -328,8 +332,7 @@ class ApproximateOracle(OracleBuilder, abc.ABC):
                             is_absolute=is_absolute,
                             download_method=None if disk_target else "direct",
                             download_target=None if disk_target else
-                            f"https://design-bench.s3-"
-                            f"us-west-1.amazonaws.com/{default}")
+                            f"{SERVER_URL}/{default}")
 
     def save_params(self, file, params):
         """a function that serializes a machine learning model and stores
